Index: src/Fl_Group.cxx
===================================================================
--- src/Fl_Group.cxx	(revision 5990)
+++ src/Fl_Group.cxx	(working copy)
@@ -536,6 +536,9 @@
 
 void Fl_Group::draw_children() {
   Fl_Widget*const* a = array();
+
+  if (clip_children()) fl_push_clip(x(), y(), w(), h());
+
   if (damage() & ~FL_DAMAGE_CHILD) { // redraw the entire thing:
     for (int i=children_; i--;) {
       Fl_Widget& o = **a++;
@@ -545,6 +548,8 @@
   } else {	// only redraw the children that need it:
     for (int i=children_; i--;) update_child(**a++);
   }
+
+  if (clip_children()) fl_pop_clip();
 }
 
 void Fl_Group::draw() {
Index: FL/Fl_Group.H
===================================================================
--- FL/Fl_Group.H	(revision 5990)
+++ FL/Fl_Group.H	(working copy)
@@ -48,7 +48,11 @@
   Fl_Group& operator=(const Fl_Group&);
 
 protected:
+  enum { CLIP_CHILDREN = 2048 };
 
+  void clip_children(int c) { if (c) set_flag(CLIP_CHILDREN); else clear_flag(CLIP_CHILDREN); }
+  int clip_children() { return (flags() & CLIP_CHILDREN) != 0; }
+
   void draw();
   void draw_child(Fl_Widget&) const;
   void draw_children();
Index: documentation/Fl_Group.html
===================================================================
--- documentation/Fl_Group.html	(revision 5990)
+++ documentation/Fl_Group.html	(working copy)
@@ -39,18 +39,19 @@
 <LI><A href=#Fl_Group.Fl_Group>Fl_Group</A></LI>
 <LI><A href=#Fl_Group.~Fl_Group>~Fl_Group</A></LI>
 <LI><A href=#Fl_Group.add>add</A></LI>
+<LI><A href=#Fl_Group.add_resizable>add_resizable</A></LI>
 </UL>
 </TD><TD align=left valign=top>
 <UL>
-<LI><A href=#Fl_Group.add_resizable>add_resizable</A></LI>
 <LI><A href=#Fl_Group.array>array</A></LI>
 <LI><A href=#Fl_Group.begin>begin</A></LI>
+<LI><A href=#Fl_Group.child>child</A></LI>
+<LI><A href=#Fl_Group.children>children</A></LI>
 </UL>
 </TD><TD align=left valign=top>
 <UL>
-<LI><A href=#Fl_Group.child>child</A></LI>
-<LI><A href=#Fl_Group.children>children</A></LI>
 <LI><A href="#Fl_Group.clear">clear</A></LI>
+<LI><A href="#Fl_Group.clip_children">clip_children</A></LI>
 <LI><A href=#Fl_Group.current>current</A></LI>
 </UL>
 </TD><TD align=left valign=top>
@@ -94,6 +95,16 @@
 href='#Fl_Group.remove'><tt>remove()</tt></a> method in that it
 affects all child widgets and deletes them from memory.</p>
 
+<H4><A name="Fl_Group.clip_children">void Fl_Group::clip_children(int c);<br>
+int Fl_Group::clip_children();</A></H4>
+
+The first method controls whether the group widget clips the drawing of
+child widgets to its bounding box.
+
+<p>The second method returns the current clipping mode.
+
+<p>The default is to not clip (0) the drawing of child widgets.
+
 <H4><A name="Fl_Group.init_sizes">void Fl_Group::init_sizes()</A></H4>
 
 The <TT>Fl_Group</TT> widget keeps track of the original widget sizes and
